@@ -26,6 +26,7 @@
 #include <QQmlContext>
 #include <QQuickStyle>
 #include <QString>
+#include <QTimer>
 
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
@@ -68,6 +69,10 @@ int main(int argc, char *argv[])
     // command line parser
     QCommandLineParser parser;
     about.setupCommandLine(&parser);
+
+    QCommandLineOption selfTestOpt(QStringLiteral("self-test"), QStringLiteral("internal, for automated testing"));
+    parser.addOption(selfTestOpt);
+
     parser.process(app);
     about.processCommandLine(&parser);
 
@@ -112,5 +117,9 @@ int main(int argc, char *argv[])
         return -1;
     }
 
+    if (parser.isSet(selfTestOpt)) {
+        QTimer::singleShot(std::chrono::milliseconds(250), &app, &QCoreApplication::quit);
+    }
+
     return app.exec();
 }
